/*
 * Copyright (c) 2000, 2001, 2002 Virtual Unlimited B.V.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/*!\file blockpad.h
 * \brief Blockcipher padding algorithms.
 * \author Bob Deblier <bob.deblier@pandora.be>
 * \ingroup BC_m
 */

#ifndef _BLOCKPAD_H
#define _BLOCKPAD_H

#include "beecrypt/beecrypt.h"

#ifdef __cplusplus
extern "C" {
#endif

BEECRYPTAPI
memchunk* pkcs5Pad  (size_t, memchunk*);
BEECRYPTAPI
memchunk* pkcs5Unpad(size_t, memchunk*);

BEECRYPTAPI
memchunk* pkcs5PadCopy  (size_t, const memchunk*);
BEECRYPTAPI
memchunk* pkcs5UnpadCopy(size_t, const memchunk*);

#ifdef __cplusplus
}
#endif

#endif
